QueryClientProvider class
Provider widget for QueryClient configuration.
This widget allows you to configure QueryClient with security options and make it available to child widgets through the widget tree.
Example:
QueryClientProvider(
config: CacheConfig(
defaultStaleTime: Duration(minutes: 5),
defaultCacheTime: Duration(minutes: 10),
),
persistenceOptions: PersistenceOptions(
enabled: true,
encryptionKey: 'your-encryption-key',
),
child: MyApp(),
)
Provide an existing client instead to reuse global configuration:
final client = QueryClient(
config: CacheConfig(
defaultCacheTime: const Duration(minutes: 10),
),
);
QueryClientProvider(
client: client,
child: MyApp(),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- QueryClientProvider
Constructors
- QueryClientProvider({required Widget child, Key? key, CacheConfig? config, PersistenceOptions? persistenceOptions, QueryClient? client})
-
Creates a provider that exposes a QueryClient to descendants.
const
Properties
- child → Widget
-
The widget below this widget in the tree.
final
- client → QueryClient?
-
Optional pre-configured QueryClient instance to reuse.
final
- config → CacheConfig?
-
Cache configuration for the QueryClient.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- persistenceOptions → PersistenceOptions?
-
Persistence options for encrypted cache storage.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< QueryClientProvider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited