QueryKey class abstract

Base type for stable query identifiers used by the cache/client registry.

Annotations

Constructors

QueryKey()
Creates a query key.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
Canonical string representation of this key.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override