ReplacementConflictPlan class final
- Inheritance
-
- Object
- ConflictRepairPlan
- ReplacementConflictPlan
Constructors
- ReplacementConflictPlan({required Object? variables, required ConflictPrecondition precondition, MutationKey? mutationKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mutationKey → MutationKey?
-
final
- precondition → ConflictPrecondition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited