AuthScope class
Exact non-secret identity under which required work was queued.
- Annotations
Constructors
Properties
- authRealm → String
-
Non-secret authentication realm identifier.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- principalId → String
-
Non-secret principal identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeKey → String
-
Stable scope key for filtering and ownership checks.
no setter
- tenantId → String
-
Non-secret tenant or account identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this scope into a JSON-safe map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override