Dependent<T> class
Represents a dependency value that is only usable when enabled is true.
Commonly created from a QueryState to gate downstream logic on successful query completion.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of<
T> (QueryState< T> state) → Dependent<T> - Creates a Dependent from a QueryState.