MutationMeta class
Metadata for mutation side effects and user-facing messages.
Constructors
Properties
- errorMessage → String?
-
Optional message shown when the mutation fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidateKeys
→ List<
QueryKey> -
Query keys to invalidate after mutation completion.
final
-
refetchKeys
→ List<
QueryKey> -
Query keys to refetch after mutation completion.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successMessage → String?
-
Optional message shown when the mutation succeeds.
final
- triggerCriticalHandler → bool
-
Whether to trigger the global critical-error handler on failure.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited