QueryConfig<T> class
Configuration for a single query in a parallel query setup.
Constructors
-
QueryConfig(QueryKey queryKey, Future<
T> queryFn(), {QueryOptions? options}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → QueryOptions?
-
Optional configuration for this query.
final
-
queryFn
→ Future<
T> Function() -
Function that returns a Future with the data.
final
- queryKey → QueryKey
-
Unique identifier for this query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited