QueryKey class abstract
Base type for stable query identifiers used by the cache/client registry.
- Annotations
Constructors
- QueryKey()
-
Creates a query key.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override