QueryMeta class
Describes optional metadata for query lifecycle side effects.
This can be attached to queries to provide UI messages and control related cache invalidation or refetch behavior after updates.
Constructors
Properties
- errorMessage → String?
-
Message shown when the operation fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invalidateKeys
→ List<
QueryKey> -
Query keys that should be invalidated after a successful operation.
final
-
refetchKeys
→ List<
QueryKey> -
Query keys that should be refetched after a successful operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successMessage → String?
-
Message shown when the operation succeeds.
final
- triggerCriticalHandler → bool
-
Whether the global critical error handler should be triggered on failure.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited