UseMutationResult<TData, TVariables> class
Convenience wrapper returned by useMutation.
Exposes the imperative mutate and reset callbacks alongside the latest MutationState and boolean helpers for common checks.
Constructors
-
UseMutationResult({required Future<
void> mutate(TVariables), required void reset(), required MutationState<TData> state}) -
const
Properties
- data → TData?
-
no setter
- error → Object?
-
no setter
- hasData → bool
-
no setter
- hasError → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIdle → bool
-
no setter
- isLoading → bool
-
no setter
- isSuccess → bool
-
no setter
-
mutate
→ Future<
void> Function(TVariables) -
final
- reset → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ MutationState<
TData> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited